"""
Use simple functions:
    from isddc import itime
    now: str = itime.Now.str

Use complex functions:
    __init__({
        'iapi': iapi.init_params_sample,
        'imysql': imysql.init_params_sample
    })

    from isddc import iapi
    from isddc import imysql

    data = iapi.get('uri')
    res = iapi.report({}, dtype='metrics')

    data = imysql.sql('SQL')
    or
    conn = imysql.db1
    cur = conn.cursor()
    cur.execute('SQL')
    data = cur.fetchall()
    cur.close()

All initialization parameters:
    __init__({
        'ialiyun': ialiyun.init_params_sample,
        'iapi':    iapi.init_params_sample,
        'idbpool': idbpool.init_params_sample,
        'iinflux': influx.init_params_sample,
        'ikafka':  ikafka.init_params_sample,
        'ikube':   ikube.init_params_sample,
        'ilog':    ilog.init_params_sample,
        'imongo':  imongo.init_params_sample,
        'imysql':  imysql.init_params_sample,
        'issh':    issh.init_params_sample,
    })
"""

__version__ = '3.1.5'
__author__ = '竹永康'
__author_email__ = 'zhuyk4@lenovo.com'

from .isddc_origin import IsddcInit       as __init__
from .isddc_origin import IsddcAliyun     as ialiyun
from .isddc_origin import IsddcAPI        as iapi
from .isddc_origin import IsddcBaseClass  as ibase
from .isddc_origin import IsddcCommand    as icmd
from .isddc_origin import IsddcCrypto     as icrypto
from .isddc_origin import IsddcDBPool     as idbpool
from .isddc_origin import IsddcDecorator  as idec
from .isddc_origin import IsddcDict       as idict
from .isddc_origin import IsddcFileSystem as ifs
from .isddc_origin import IsddcFunction   as ifunc
from .isddc_origin import IsddcInflux     as influx
from .isddc_origin import IsddcKafka      as ikafka
from .isddc_origin import IsddcKube       as ikube
from .isddc_origin import IsddcLog        as ilog
from .isddc_origin import IsddcMongo      as imongo
from .isddc_origin import IsddcMultiTask  as imt
from .isddc_origin import IsddcMysql      as imysql
from .isddc_origin import IsddcSSH        as issh
from .isddc_origin import IsddcTime       as itime
from .isddc_origin import IsddcAsync      as iasync

# Isddc Config.
inf: idict = None
# Initialization parameters passed to __init__.

__all__ = [
    'ialiyun',
    'iapi',
    'ibase',
    'icmd',
    'icrypto',
    'idbpool',
    'idec',
    'idict',
    'ifs',
    'influx',
    'ikafka',
    'ikube',
    'ilog',
    'imongo',
    'imt',
    'imysql',
    'issh',
    'itime',
    'iasync',
    'ifunc',
    'inf'
]

isddc_aliyun     = \
isddc_api        = \
isddc_baseclass  = \
isddc_command    = \
isddc_crypto     = \
isddc_dbpool     = \
isddc_decorator  = \
isddc_dict       = \
isddc_filesystem = \
isddc_function   = \
isddc_influx     = \
isddc_kafka      = \
isddc_kube       = \
isddc_log        = \
isddc_mongo      = \
isddc_multitask  = \
isddc_mysql      = \
isddc_ssh        = \
isddc_time       = \
isddc_origin     = \
isddc_origin.DenyImport
